@@ -82,3 +82,62 @@ class FeatureNotSupported(CanonicalException):
         "This feature is either not configured, deprecated or retired. Consult "
         "the API documentation for more information."
     )
+
+
+class BaseTokenException(CanonicalException):
+
+    def __init__(self, *args, **kwargs):
+        self.token = kwargs.pop('token')
+        super().__init__(*args, **kwargs)
+
+
+class InvalidToken(CanonicalException):
+    code = 'BEARER_TOKEN_INVALID'
+    http_status_code = 403
+    message = "The authentication token is not valid."
+
+
+class InvalidScope(BaseTokenException):
+    code = 'BEARER_TOKEN_NOT_AUTHORIZED'
+    http_status_code = 403
+    message = "The provided token has an invalid scope."
+
+
+class InvalidAudience(BaseTokenException):
+    code = 'BEARER_TOKEN_AUDIENCE_INVALID'
+    http_status_code = 403
+    message = "The audience of the authentication token is invalid."
+
+
+class ExpiredSignatureError(BaseTokenException):
+    code = 'BEARER_TOKEN_SIGNATURE_EXPIRED'
+    http_status_code = 403
+    message = "The authentication token is expired."
+
+
+class MissingToken(BaseTokenException):
+    code = 'BEARER_TOKEN_MISSING'
+    http_status_code = 403
+    message = "The authentication token is expired."
+    hint = "Provide the Bearer token using the Authorization header."
+
+
+class CrossSiteRequestForgeryTokenExpired(BaseTokenException):
+    code = 'CSRF_TOKEN_EXPIRED'
+    http_status_code = 403
+    message = "The presented CSRF token is expired."
+    hint = "Request a new token."
+
+
+class CrossSiteRequestForgeryTokenMissing(BaseTokenException):
+    code = 'CSRF_TOKEN_MISSING'
+    http_status_code = 403
+    message = "The presented CSRF token is missing."
+    hint = "Request a new token."
+
+
+class CrossSiteRequestForgeryTokenInvalid(BaseTokenException):
+    code = 'CSRF_TOKEN_INVALID'
+    http_status_code = 403
+    message = "The presented CSRF token is not valid."
+    hint = "Request a new token."
