@@ -106,10 +106,10 @@ class Repository(metaclass=abc.ABCMeta):
         return self
 
     def __exit__(self, cls, exc, tb):
-        self.teardown_context(cls, exc, tb)
+        pass
 
     async def __aenter__(self):
         return self
 
     async def __aexit__(self, cls, exc, tb):
-        pass
+        self.async_teardown_context(cls, exc, tb)
